"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCommandSynopsis = void 0;
const optionToString_1 = require("./optionToString");
const getCommandSynopsis = function ({ command }) {
    const requiredOptions = command.optionDefinitions.filter((optionDefinition) => (optionDefinition.defaultOption === undefined || !optionDefinition.defaultOption) &&
        (optionDefinition.isRequired !== undefined && optionDefinition.isRequired));
    const optionalOptions = command.optionDefinitions.filter((optionDefinition) => (optionDefinition.defaultOption === undefined || !optionDefinition.defaultOption) &&
        (optionDefinition.isRequired === undefined || !optionDefinition.isRequired));
    const defaultOption = command.optionDefinitions.find((optionDefinition) => optionDefinition.defaultOption === true);
    const requiredOptionsString = requiredOptions.
        map((option) => optionToString_1.optionToString({ option })).
        join(' ');
    const optionalOptionsString = optionalOptions.
        map((option) => optionToString_1.optionToString({ option })).
        join(' ');
    let synopsis = command.name;
    if (requiredOptionsString) {
        synopsis += ` ${requiredOptionsString}`;
    }
    if (optionalOptionsString) {
        synopsis += ` [${optionalOptionsString}]`;
    }
    if (defaultOption) {
        synopsis += defaultOption.isRequired ?
            ` ${optionToString_1.optionToString({ option: defaultOption })}` :
            ` [${optionToString_1.optionToString({ option: defaultOption })}]`;
    }
    return synopsis;
};
exports.getCommandSynopsis = getCommandSynopsis;
